@@ -698,6 +698,8 @@ from bitmovin_api_sdk.models.stream_mode import StreamMode
 from bitmovin_api_sdk.models.stream_per_title_fixed_resolution_and_bitrate_settings import StreamPerTitleFixedResolutionAndBitrateSettings
 from bitmovin_api_sdk.models.stream_per_title_settings import StreamPerTitleSettings
 from bitmovin_api_sdk.models.stream_selection_mode import StreamSelectionMode
+from bitmovin_api_sdk.models.streams_config_response import StreamsConfigResponse
+from bitmovin_api_sdk.models.streams_config_update_request import StreamsConfigUpdateRequest
 from bitmovin_api_sdk.models.streams_live_update_request import StreamsLiveUpdateRequest
 from bitmovin_api_sdk.models.streams_video_create_request import StreamsVideoCreateRequest
 from bitmovin_api_sdk.models.streams_video_encoding_status import StreamsVideoEncodingStatus
